@@ -16,7 +16,8 @@
 """
 import sys
 
-from logilab.common.compat import enumerate
+from logilab.common.compat import builtins
+BUILTINS_NAME = builtins.__name__
 from logilab import astng
 from logilab.astng import YES, Instance, unpack_infer
 
@@ -24,6 +25,7 @@ from pylint.checkers import BaseChecker
 from pylint.checkers.utils import is_empty, is_raising
 from pylint.interfaces import IASTNGChecker
 
+
 MSGS = {
     'E0701': (
     'Bad except clauses order (%s)',
@@ -51,16 +53,12 @@ MSGS = {
               'Used when a custom exception class is raised but doesn\'t \
               inherit from the builtin "Exception" class.'),
     }
-if sys.version_info < (2, 5):
-    MSGS['E0710'] = ('Raising a new style class',
-                     'Used when a new style class is raised since it\'s not \
-                      possible with python < 2.5.')
-else:
-    MSGS['E0710'] = ('Raising a new style class which doesn\'t inherit from \
+
+MSGS['E0710'] = ('Raising a new style class which doesn\'t inherit from \
 BaseException',
                      'Used when a new style class which doesn\'t inherit from \
-                      BaseException raised since it\'s not possible with \
-                      python < 2.5.')
+                      BaseException is raised since it\'s not possible with \
+                      python >= 2.5.')
 
 
 class ExceptionsChecker(BaseChecker):
@@ -79,9 +77,9 @@ class ExceptionsChecker(BaseChecker):
     def visit_raise(self, node):
         """visit raise possibly inferring value"""
         # ignore empty raise
-        if node.type is None:
+        if node.exc is None:
             return
-        expr = node.type
+        expr = node.exc
         if self._check_raise_value(node, expr):
             return
         else:
@@ -107,7 +105,10 @@ class ExceptionsChecker(BaseChecker):
                  isinstance(expr, (astng.List, astng.Dict, astng.Tuple, 
                                    astng.Module, astng.Function)):
             self.add_message('E0702', node=node, args=expr.name)
-        elif isinstance(expr, astng.Name) and expr.name == 'NotImplemented':
+        elif ( (isinstance(expr, astng.Name) and expr.name == 'NotImplemented')
+               or (isinstance(expr, astng.CallFunc) and
+                   isinstance(expr.func, astng.Name) and
+                   expr.func.name == 'NotImplemented') ):
             self.add_message('E0711', node=node)
         elif isinstance(expr, astng.BinOp) and expr.op == '%':
             self.add_message('W0701', node=node)
@@ -116,7 +117,7 @@ class ExceptionsChecker(BaseChecker):
                 expr = expr._proxied
             if (isinstance(expr, astng.Class) and
                     not inherit_from_std_ex(expr) and
-                    expr.root().name != '__builtin__'):
+                    expr.root().name != BUILTINS_NAME):
                 if expr.newstyle:
                     self.add_message('E0710', node=node)
                 else:
@@ -142,7 +143,7 @@ class ExceptionsChecker(BaseChecker):
                 # check if a "except:" is followed by some other
                 # except
                 elif index < (nb_handlers - 1):
-                    msg = 'empty except clause should always appears last'
+                    msg = 'empty except clause should always appear last'
                     self.add_message('E0701', node=node, args=msg)
             else:
                 try:
@@ -166,12 +167,18 @@ class ExceptionsChecker(BaseChecker):
                         self.add_message('W0703', node=handler.type)
                 exceptions_classes += excs
 
+
+if sys.version_info < (3, 0):
+    EXCEPTIONS_MODULE = "exceptions"
+else:
+    EXCEPTIONS_MODULE = "builtins"
+
 def inherit_from_std_ex(node):
     """return true if the given class node is subclass of
     exceptions.Exception
     """
     if node.name in ('Exception', 'BaseException') \
-            and node.root().name == 'exceptions':
+            and node.root().name == EXCEPTIONS_MODULE:
         return True
     for parent in node.ancestors(recurs=False):
         if inherit_from_std_ex(parent):
@@ -181,3 +188,4 @@ def inherit_from_std_ex(node):
 def register(linter):
     """required method to auto register this checker"""
     linter.register_checker(ExceptionsChecker(linter))
+
