@@ -38,7 +38,7 @@ def guess_encoding(string):
     """try to guess encoding from a python file as string
     return None if not found
     """
-    assert type(string) is type(''), type(string)
+    assert isinstance(string, str), type(string)
     # check for UTF-8 byte-order mark
     if string.startswith('\xef\xbb\xbf'):
         return 'UTF-8'
@@ -57,10 +57,6 @@ MSGS = {
     'E0502': ('Wrong encoding specified (%s)',
               'Used when a known encoding is specified but the file doesn\'t \
               seem to be actually in this encoding.'),
-    'E0503': ('Unknown encoding specified (%s)',
-              'Used when an encoding is specified, but it\'s unknown to Python.'
-              ),
-
     'W0511': ('%s',
               'Used when a warning note as FIXME or XXX is detected.'),
     }
@@ -103,8 +99,6 @@ separated by a comma.'
                     unicode(data, encoding)
                 except UnicodeError:
                     self.add_message('E0502', args=encoding, line=1)
-                except LookupError:
-                    self.add_message('E0503', args=encoding, line=1)
         del data
         # warning notes in the code
         stream.seek(0)
