@@ -22,7 +22,6 @@ import string
 from logilab import astng
 from pylint.interfaces import IASTNGChecker
 from pylint.checkers import BaseChecker
-from logilab.common.compat import set
 
 MSGS = {
     'E9900': ("Unsupported format character %r (%#02x) at index %d",
@@ -197,6 +196,7 @@ class StringFormatChecker(BaseChecker):
                           isinstance(args, astng.Tuple) or
                           isinstance(args, astng.List) or
                           isinstance(args, astng.ListComp) or
+                          isinstance(args, astng.SetComp) or
                           isinstance(args, astng.GenExpr) or
                           isinstance(args, astng.Backquote) or
                           isinstance(args, astng.Lambda)):
@@ -218,6 +218,8 @@ class StringFormatChecker(BaseChecker):
                           isinstance(args, astng.Dict) or
                           isinstance(args, astng.List) or
                           isinstance(args, astng.ListComp) or
+                          isinstance(args, astng.SetComp) or
+                          isinstance(args, astng.DictComp) or
                           isinstance(args, astng.GenExpr) or
                           isinstance(args, astng.Backquote) or
                           isinstance(args, astng.Lambda) or
