@@ -19,14 +19,15 @@
 """
 
 from logilab import astng
+from logilab.common.compat import builtins
+BUILTINS_NAME = builtins.__name__
 
 try:
     # python >= 2.4
-    COMP_NODE_TYPES = (astng.ListComp, astng.GenExpr)
-    FOR_NODE_TYPES = (astng.For, astng.Comprehension, astng.Comprehension)
+    COMP_NODE_TYPES = (astng.ListComp, astng.SetComp, astng.DictComp,
+                       astng.GenExpr)
 except AttributeError:
     COMP_NODE_TYPES = astng.ListComp
-    FOR_NODE_TYPES = (astng.For, astng.Comprehension)
 
 def safe_infer(node):
     """return the inferred value for the given node.
@@ -48,7 +49,7 @@ def is_super(node):
     """return True if the node is referencing the "super" builtin function
     """
     if getattr(node, 'name', None) == 'super' and \
-           node.root().name == '__builtin__':
+           node.root().name == BUILTINS_NAME:
         return True
     return False
 
@@ -70,27 +71,27 @@ def is_empty(body):
     """return true if the given node does nothing but 'pass'"""
     return len(body) == 1 and isinstance(body[0], astng.Pass)
 
-builtins = __builtins__.copy()
+builtins =  __builtins__.copy()
 SPECIAL_BUILTINS = ('__builtins__',) # '__path__', '__file__')
 
 def is_builtin(name): # was is_native_builtin
     """return true if <name> could be considered as a builtin defined by python
     """
-    if builtins.has_key(name):
+    if name in builtins:
         return True
     if name in SPECIAL_BUILTINS:
         return True
     return False
 
-def is_defined_before(var_node, comp_node_types=COMP_NODE_TYPES):
-    """return True if the variable node is defined by a parent node (list
-    or generator comprehension, lambda) or in a previous sibling node
-    one the same line (statement_defining ; statement_using)
+def is_defined_before(var_node):
+    """return True if the variable node is defined by a parent node (list,
+    set, dict, or generator comprehension, lambda) or in a previous sibling
+    node on the same line (statement_defining ; statement_using)
     """
     varname = var_node.name
     _node = var_node.parent
     while _node:
-        if isinstance(_node, comp_node_types):
+        if isinstance(_node, COMP_NODE_TYPES):
             for ass_node in _node.nodes_of_class(astng.AssName):
                 if ass_node.name == varname:
                     return True
