@@ -18,7 +18,6 @@
 
 from copy import copy
 
-from logilab.common.compat import enumerate
 from logilab import astng
 from logilab.astng import are_exclusive, builtin_lookup
 
@@ -111,8 +110,8 @@ __init__ files.'}),
                ("dummy-variables-rgx",
                 {'default': ('_|dummy'),
                  'type' :'regexp', 'metavar' : '<regexp>',
-                 'help' : 'A regular expression matching names used \
-                 for dummy variables (i.e. not used).'}),
+                 'help' : 'A regular expression matching the beginning of \
+                  the name of dummy variables (i.e. not used).'}),
                ("additional-builtins",
                 {'default': (), 'type' : 'csv',
                  'metavar' : '<comma separated list>',
@@ -182,7 +181,7 @@ builtins. Remember that you should avoid to define new builtins when possible.'
     def visit_genexpr(self, node):
         """visit genexpr: update consumption analysis variable
         """
-        self._to_consume.append((copy(node.locals), {}, 'genexpr'))
+        self._to_consume.append((copy(node.locals), {}, 'comprehension'))
 
     def leave_genexpr(self, _):
         """leave genexpr: update consumption analysis variable
@@ -190,12 +189,34 @@ builtins. Remember that you should avoid to define new builtins when possible.'
         # do not check for not used locals here
         self._to_consume.pop()
 
+    def visit_dictcomp(self, node):
+        """visit dictcomp: update consumption analysis variable
+        """
+        self._to_consume.append((copy(node.locals), {}, 'comprehension'))
+
+    def leave_dictcomp(self, _):
+        """leave dictcomp: update consumption analysis variable
+        """
+        # do not check for not used locals here
+        self._to_consume.pop()
+
+    def visit_setcomp(self, node):
+        """visit setcomp: update consumption analysis variable
+        """
+        self._to_consume.append((copy(node.locals), {}, 'comprehension'))
+
+    def leave_setcomp(self, _):
+        """leave setcomp: update consumption analysis variable
+        """
+        # do not check for not used locals here
+        self._to_consume.pop()
+
     def visit_function(self, node):
         """visit function: update consumption analysis variable and check locals
         """
         globs = node.root().globals
         for name, stmt in node.items():
-            if globs.has_key(name) and not isinstance(stmt, astng.Global):
+            if name in globs and not isinstance(stmt, astng.Global):
                 line = globs[name][0].lineno
                 self.add_message('W0621', args=(name, line), node=stmt)
             elif is_builtin(name):
@@ -350,14 +371,14 @@ builtins. Remember that you should avoid to define new builtins when possible.'
             # scope, ignore it. This prevents to access this scope instead of
             # the globals one in function members when there are some common
             # names. The only exception is when the starting scope is a
-            # genexpr and its direct outer scope is a class
+            # comprehension and its direct outer scope is a class
             if scope_type == 'class' and i != start_index and not (
-                base_scope_type == 'genexpr' and i == start_index-1):
+                base_scope_type == 'comprehension' and i == start_index-1):
                 # XXX find a way to handle class scope in a smoother way
                 continue
             # the name has already been consumed, only check it's not a loop
             # variable used outside the loop
-            if consumed.has_key(name):
+            if name in consumed:
                 self._loopvar_name(node, name)
                 break
             # mark the name as consumed if it's defined in this scope
@@ -366,42 +387,41 @@ builtins. Remember that you should avoid to define new builtins when possible.'
                 consumed[name] = to_consume[name]
             except KeyError:
                 continue
-            else:
-                # checks for use before assignment
-                defnode = assign_parent(to_consume[name][0])
-                if defnode is not None:
-                    defstmt = defnode.statement()
-                    defframe = defstmt.frame()
-                    maybee0601 = True
-                    if not frame is defframe:
+            # checks for use before assignment
+            defnode = assign_parent(to_consume[name][0])
+            if defnode is not None:
+                defstmt = defnode.statement()
+                defframe = defstmt.frame()
+                maybee0601 = True
+                if not frame is defframe:
+                    maybee0601 = False
+                elif defframe.parent is None:
+                    # we are at the module level, check the name is not
+                    # defined in builtins
+                    if name in defframe.scope_attrs or builtin_lookup(name)[1]:
                         maybee0601 = False
-                    elif defframe.parent is None:
-                        # we are at the module level, check the name is not
-                        # defined in builtins
-                        if name in defframe.scope_attrs or builtin_lookup(name)[1]:
-                            maybee0601 = False
-                    else:
-                        # we are in a local scope, check the name is not
-                        # defined in global or builtin scope
-                        if defframe.root().lookup(name)[1]:
-                            maybee0601 = False
-                    if (maybee0601
-                        and stmt.fromlineno <= defstmt.fromlineno
-                        and not is_defined_before(node)
-                        and not are_exclusive(stmt, defstmt, ('NameError', 'Exception', 'BaseException'))):
-                        if defstmt is stmt and isinstance(node, (astng.DelName,
-                                                                 astng.AssName)):
-                            self.add_message('E0602', args=name, node=node)
-                        elif self._to_consume[-1][-1] != 'lambda':
-                            # E0601 may *not* occurs in lambda scope
-                            self.add_message('E0601', args=name, node=node)
-                if not isinstance(node, astng.AssName): # Aug AssName
-                    del to_consume[name]
                 else:
-                    del consumed[name]
-                # check it's not a loop variable used outside the loop
-                self._loopvar_name(node, name)
-                break
+                    # we are in a local scope, check the name is not
+                    # defined in global or builtin scope
+                    if defframe.root().lookup(name)[1]:
+                        maybee0601 = False
+                if (maybee0601
+                    and stmt.fromlineno <= defstmt.fromlineno
+                    and not is_defined_before(node)
+                    and not are_exclusive(stmt, defstmt, ('NameError', 'Exception', 'BaseException'))):
+                    if defstmt is stmt and isinstance(node, (astng.DelName,
+                                                             astng.AssName)):
+                        self.add_message('E0602', args=name, node=node)
+                    elif self._to_consume[-1][-1] != 'lambda':
+                        # E0601 may *not* occurs in lambda scope
+                        self.add_message('E0601', args=name, node=node)
+            if not isinstance(node, astng.AssName): # Aug AssName
+                del to_consume[name]
+            else:
+                del consumed[name]
+            # check it's not a loop variable used outside the loop
+            self._loopvar_name(node, name)
+            break
         else:
             # we have not found the name, if it isn't a builtin, that's an
             # undefined name !
@@ -491,6 +511,24 @@ builtins. Remember that you should avoid to define new builtins when possible.'
         return None
 
 
+class VariablesChecker3k(VariablesChecker):
+    '''Modified variables checker for 3k'''
+    # listcomp have now also their scope
+
+    def visit_listcomp(self, node):
+        """visit dictcomp: update consumption analysis variable
+        """
+        self._to_consume.append((copy(node.locals), {}, 'comprehension'))
+
+    def leave_listcomp(self, _):
+        """leave dictcomp: update consumption analysis variable
+        """
+        # do not check for not used locals here
+        self._to_consume.pop()
+
+import sys
+if sys.version_info >= (3, 0):
+    VariablesChecker = VariablesChecker3k
 
 
 def register(linter):
