@@ -26,7 +26,7 @@ from os.path import exists, isfile, join, expanduser, abspath, dirname
 # pylint home is used to save old runs results ################################
 
 USER_HOME = expanduser('~')
-if os.environ.has_key('PYLINTHOME'):
+if 'PYLINTHOME' in os.environ:
     PYLINT_HOME = os.environ['PYLINTHOME']
     if USER_HOME == '~':
         USER_HOME = dirname(PYLINT_HOME)
@@ -60,14 +60,19 @@ def load_results(base):
     except:
         return {}
 
+if sys.version_info < (3, 0):
+    _PICK_MOD = 'w'
+else:
+    _PICK_MOD = 'wb'
+
 def save_results(results, base):
     """pickle results"""
     data_file = get_pdata_path(base, 1)
     try:
-        pickle.dump(results, open(data_file, 'w'))
+        pickle.dump(results, open(data_file, _PICK_MOD))
     except (IOError, OSError), ex:
         print >> sys.stderr, 'Unable to create file %s: %s' % (data_file, ex)
-    
+
 # location of the configuration file ##########################################
 
 
@@ -83,7 +88,7 @@ def find_pylintrc():
             curdir = abspath(join(curdir, '..'))
             if isfile(join(curdir, 'pylintrc')):
                 return join(curdir, 'pylintrc')
-    if os.environ.has_key('PYLINTRC') and exists(os.environ['PYLINTRC']):
+    if 'PYLINTRC' in os.environ and exists(os.environ['PYLINTRC']):
         pylintrc = os.environ['PYLINTRC']
     else:
         user_home = expanduser('~')
