@@ -41,11 +41,9 @@ from logilab.common.optik_ext import check_csv
 from logilab.common.modutils import load_module_from_name
 from logilab.common.interface import implements
 from logilab.common.textutils import splitstrip
-from logilab.common.fileutils import norm_open
 from logilab.common.ureports import Table, Text, Section
 from logilab.common.graph import ordered_nodes
 from logilab.common.__pkginfo__ import version as common_version
-from logilab.common.compat import set
 
 from logilab.astng import MANAGER, nodes
 from logilab.astng.__pkginfo__ import version as astng_version
@@ -189,13 +187,13 @@ convention) / statement) * 10)',
 than 10 (10 is the highest note). You have access to the variables errors \
 warning, statement which respectively contain the number of errors / warnings\
  messages and the total number of statements analyzed. This is used by the \
- global evaluation report (R0004).'}),
+ global evaluation report (RP0004).'}),
 
                ('comment',
                 {'default': 0, 'type' : 'yn', 'metavar' : '<y_or_n>',
                  'group': 'Reports', 'level': 1,
                  'help' : 'Add a comment according to your evaluation note. \
-This is used by the global evaluation report (R0004).'}),
+This is used by the global evaluation report (RP0004).'}),
 
                ('enable',
                 {'type' : 'csv', 'metavar': '<msg ids>',
@@ -531,15 +529,14 @@ This is used by the global evaluation report (R0004).'}),
     def get_astng(self, filepath, modname):
         """return a astng representation for a module"""
         try:
-            return MANAGER.astng_from_file(filepath, modname)
+            return MANAGER.astng_from_file(filepath, modname, source=True)
         except SyntaxError, ex:
             self.add_message('E0001', line=ex.lineno, args=ex.msg)
         except KeyboardInterrupt:
             raise
         except Exception, ex:
-            #if __debug__:
-            #    import traceback
-            #    traceback.print_exc()
+            # import traceback
+            # traceback.print_exc()
             self.add_message('F0002', args=(ex.__class__, ex))
 
     def check_astng_module(self, astng, walker, rawcheckers):
@@ -549,7 +546,7 @@ This is used by the global evaluation report (R0004).'}),
             self.add_message('I0001', args=astng.name)
         else:
             #assert astng.file.endswith('.py')
-            stream = norm_open(astng.file)
+            stream = open(astng.file, 'U')
             # invoke IRawChecker interface on self to fetch module/block
             # level options
             self.process_module(stream)
@@ -609,7 +606,7 @@ This is used by the global evaluation report (R0004).'}),
         else:
             stats['global_note'] = note
             msg = 'Your code has been rated at %.2f/10' % note
-            if old_stats.has_key('global_note'):
+            if 'global_note' in old_stats:
                 msg += ' (previous run: %.2f/10)' % old_stats['global_note']
             if self.config.comment:
                 msg = '%s\n%s' % (msg, config.get_note_message(note))
@@ -630,10 +627,9 @@ def report_messages_stats(sect, stats, _):
     if not stats['by_msg']:
         # don't print this report when we didn't detected any errors
         raise EmptyReport()
-    in_order = [(value, msg_id)
-                for msg_id, value in stats['by_msg'].items()
-                if not msg_id.startswith('I')]
-    in_order.sort()
+    in_order = sorted([(value, msg_id) 
+                       for msg_id, value in stats['by_msg'].items()
+                       if not msg_id.startswith('I')])
     in_order.reverse()
     lines = ('message id', 'occurrences')
     for value, msg_id in in_order:
@@ -838,7 +834,12 @@ been issued by analysing pylint output status code
             # by file parameters, so re-set it here, but before command line
             # parsing so it's still overrideable by command line option
             linter.set_reporter(reporter)
-        args = linter.load_command_line_configuration(args)
+        try:
+            args = linter.load_command_line_configuration(args)
+        except SystemExit, exc:
+            if exc.code == 2: # bad options
+                exc.code = 32
+            raise
         if not args:
             print linter.help()
             sys.exit(32)
@@ -847,11 +848,9 @@ been issued by analysing pylint output status code
         sys.path.insert(0, os.getcwd())
         if self.linter.config.profile:
             print >> sys.stderr, '** profiled run'
-            from hotshot import Profile, stats
-            prof = Profile('stones.prof')
-            prof.runcall(linter.check, args)
-            prof.close()
-            data = stats.load('stones.prof')
+            import cProfile, pstats
+            cProfile.runctx('linter.check(%r)' % args, globals(), locals(), 'stones.prof' )
+            data = pstats.Stats('stones.prof')
             data.strip_dirs()
             data.sort_stats('time', 'calls')
             data.print_stats(30)
