@@ -18,9 +18,8 @@
 import unittest
 import sys
 import re
-import new
-from os import linesep
-from os.path import exists
+from os import linesep, getcwd
+from os.path import exists, abspath, dirname, join
 
 from logilab.common import testlib
 
@@ -37,7 +36,6 @@ linter.config.persistent = 0
 checkers.initialize(linter)
 linter.global_set_option('required-attributes', ('__revision__',))
 
-PY23 = sys.version_info >= (2, 3)
 PY26 = sys.version_info >= (2, 6)
 
 
@@ -51,7 +49,10 @@ else:
 
 INFO_TEST_RGX = re.compile('^func_i\d\d\d\d$')
 
-def exception_str(ex):
+MSG_DIR = join(dirname(abspath(__file__)), 'messages')
+INPUT_DIR = join(dirname(abspath(__file__)), 'input')
+
+def exception_str(self, ex):
     """function used to replace default __str__ method of exception instances"""
     return 'in %s\n:: %s' % (ex.file, ', '.join(ex.args))
 
@@ -94,31 +95,29 @@ class LintTestUsingModule(testlib.TestCase):
             # need finalization to restore a correct state
             self.linter.reporter.finalize()
             ex.file = tocheck
-            ex.__str__ = new.instancemethod(exception_str, ex, None)
+            print ex
+            ex.__str__ = exception_str
             raise
+        got = self.linter.reporter.finalize().strip()
+        self.assertMultiLineEqual(got, self._get_expected())
+
+    def _get_expected(self):
         if self.module.startswith('func_noerror_'):
             expected = ''
         else:
             output = open(self.output)
             expected = output.read().strip()
             output.close()
-        got = self.linter.reporter.finalize().strip()
-        try:
-            self.assertMultiLineEqual(got, expected)
-        except Exception, ex:
-            # doesn't work with py 2.5
-            #ex.file = tocheck
-            #ex.__str__ = new.instancemethod(exception_str, ex, None)
-            raise AssertionError('%s: %s' % (self.module, ex)), None, sys.exc_info()[-1]
+        return expected
 
 class LintTestUsingFile(LintTestUsingModule):
 
     _TEST_TYPE = 'file'
 
     def test_functionality(self):
-        tocheck = [self.package+'/' + self.module + '.py']
+        tocheck = [join(INPUT_DIR, self.module + '.py')]
         if self.depends:
-            tocheck += [self.package+'/%s' % name for name, file in self.depends]
+            tocheck += [join(INPUT_DIR, name) for name, _file in self.depends]
         self._test(tocheck)
 
 
@@ -127,18 +126,16 @@ class TestTests(testlib.TestCase):
     @testlib.tag('coverage')
     def test_exhaustivity(self):
         # skip fatal messages
-        todo = [msgid for msgid in linter._messages.keys() if msgid[0] != 'F']
-        for msgid in test_reporter.message_ids.keys():
+        todo = [msgid for msgid in linter._messages if msgid[0] != 'F']
+        for msgid in test_reporter.message_ids:
             try:
                 todo.remove(msgid)
             except ValueError:
                 continue
         todo.sort()
         if PY26:
-            self.assertEqual(todo, ['E0503', 'E1122', 'I0001'])
-        elif PY23:
-            self.assertEqual(todo, ['E0503', 'I0001'])
-        else: # python < 2.3
+            self.assertEqual(todo, ['E1122', 'I0001'])
+        else:
             self.assertEqual(todo, ['I0001'])
 
 #bycat = {}
@@ -158,6 +155,18 @@ class TestTests(testlib.TestCase):
 # I: 5
 # total 130
 
+class LintTestNonExistentModuleTC(LintTestUsingModule):
+    module = 'nonexistent'
+    _get_expected = lambda self: 'F:  1: No module named nonexistent'
+    tags = testlib.Tags(('generated','pylint_input_%s' % module))
+
+class LintTestNonExistentFileTC(LintTestUsingFile):
+    module = join(INPUT_DIR, 'nonexistent.py')
+    _get_expected = lambda self: 'F:  1: No module named %s' % self.module[len(getcwd())+1 :]
+    tags = testlib.Tags(('generated', 'pylint_input_%s' % module))
+    def test_functionality(self):
+        self._test([self.module])
+
 def make_tests(filter_rgx):
     """generate tests classes from test info
 
@@ -168,10 +177,7 @@ def make_tests(filter_rgx):
     else:
         is_to_run = lambda x: 1
     tests = []
-    for module_file, messages_file in get_tests_info('func_', '.py') + [('nonexistant', 'messages/nonexistant.txt')]:
-        # skip those tests with python >= 2.3 since py2.3 detects them by itself
-        if PY23 and module_file == "func_unknown_encoding.py": #"func_nonascii_noencoding.py"):
-            continue
+    for module_file, messages_file in get_tests_info('func_', '.py'):
         pyrestr = module_file.rsplit('_py', 1)[-1][:-3]
         if pyrestr.isdigit(): # '24', '25'...
             if sys.version_info < tuple([int(i) for i in pyrestr]):
@@ -197,7 +203,7 @@ def make_tests(filter_rgx):
 
         class LintTestUsingFileTC(LintTestUsingFile):
             module = module_file.replace('.py', '')
-            output = exists(messages_file + '2') and (messages_file + '2') or messages_file
+            output = messages_file
             depends = dependencies or None
             tags = testlib.Tags(('generated', 'pylint_input_%s' % module))
         tests.append(LintTestUsingFileTC)
@@ -210,8 +216,13 @@ def make_tests(filter_rgx):
 ##         depends = dependencies or None
 ##     tests.append(LintTestSubclass)
 
+    if is_to_run('nonexistent'):
+        tests.append(LintTestNonExistentModuleTC)
+        if not MODULES_ONLY:
+            tests.append(LintTestNonExistentFileTC)
+
     class LintBuiltinModuleTest(LintTestUsingModule):
-        output = 'messages/builtin_module.txt'
+        output = join(MSG_DIR, 'builtin_module.txt')
         module = 'sys'
         def test_functionality(self):
             self._test(['sys'])
