@@ -19,7 +19,7 @@ class DependenciesGraphTC(unittest.TestCase):
     def test_dependencies_graph(self):
         imports.dependencies_graph(self.dest, {'labas': ['hoho', 'yep'],
                                                'hoho': ['yep']})
-        self.assertEquals(open(self.dest).read().strip(),
+        self.assertEqual(open(self.dest).read().strip(),
                           '''
 digraph "dependencies_graph" {
 rankdir=LR
