@@ -27,7 +27,6 @@ from logilab.common.modutils import modpath_from_file, get_module_files, \
 from logilab.common.textutils import normalize_text
 from logilab.common.configuration import rest_format_section
 from logilab.common.ureports import Section
-from logilab.common.compat import set
 
 from logilab.astng import nodes, Module
 
@@ -56,17 +55,18 @@ MSG_TYPES_STATUS = {
     'F' : 1
     }
 
+_MSG_ORDER = 'EWRCIF'
+
 def sort_msgs(msgids):
     """sort message identifiers according to their category first"""
-    msg_order = 'EWRCIF'
-    def cmp_func(msgid1, msgid2):
-        """comparison function for two message identifiers"""
-        if msgid1[0] != msgid2[0]:
-            return cmp(msg_order.index(msgid1[0]), msg_order.index(msgid2[0]))
-        else:
-            return cmp(msgid1, msgid2)
-    msgids.sort(cmp_func)
-    return msgids
+    msgs = {}
+    for msg in msgids:
+        msgs.setdefault(msg[0], []).append(msg)
+    result = []
+    for m_id in _MSG_ORDER:
+        if m_id in msgs:
+            result.extend( sorted(msgs[m_id]) )
+    return result
 
 def get_module_and_frameid(node):
     """return the module name and the frame id in the module"""
@@ -127,7 +127,7 @@ class MessagesHandlerMixIn:
         chkid = None
         for msgid, (msg, msgdescr) in msgs_dict.items():
             # avoid duplicate / malformed ids
-            assert not self._messages.has_key(msgid), \
+            assert msgid not in self._messages, \
                    'Message id %r is already defined' % msgid
             assert chkid is None or chkid == msgid[1:3], \
                    'Inconsistent checker part in message id %r' % msgid
@@ -291,6 +291,8 @@ class MessagesHandlerMixIn:
         for checker in self.sort_checkers():
             if checker.name == 'master':
                 prefix = 'Main '
+                print "Options"
+                print '-------\n'
                 if checker.options:
                     for section, options in checker.options_by_section():
                         if section is None:
@@ -315,6 +317,7 @@ class MessagesHandlerMixIn:
             title = '%s checker' % checker
             print title
             print '-' * len(title)
+            print
             if options:
                 title = 'Options'
                 print title
@@ -413,7 +416,7 @@ class ReportsHandlerMixIn:
         for key, value in kwargs.items():
             if key[-1] == '_':
                 key = key[:-1]
-            assert not self.stats.has_key(key)
+            assert key not in self.stats
             self.stats[key] = value
         return self.stats
 
